---
title: Project Description
---

# Project Description

"Research is to see what everybody else has seen, and to think what nobody else has thought." —Albert Szent-Györgyi

## General Project Description

---

Our iGEM team MSP-Maastricht is dedicated to addressing coastal eutrophication through a sustainable and circular approach. This problem is particularly relevant to our team, as alleviating it is a step towards overcoming the nitrogen crisis faced by the Netherlands. Nitrogen pollution from agriculture, transport, and industry sectors has become a global concern. With agriculture being a major economic contributor of the Netherlands, excess fertilizer run-off has led to pollution of our many waterways. This then results in its spread into seawater, causing ocean acidification, hypoxia, and algal blooms, which further exacerbate climate change and damage to the oceans, a major environmental and economic asset. (UNEP, 2019; KVK, 2023). To minimize damage from fertilizer leaching we propose nitrate assimilation from coastal waters, where the concentration is the highest, for single-cell proteins (SCPs) production. 

For this to be achieved, our team will utilize a genetically modified strain of *Vibrio natriegens (V. natriegens)*, which thrives in high-salinity environments. Through the genetic introduction of a nitrate transporter, nitrate reductase (Nas), and nitrite reductase (Nir) derived from *Klebsiella oxytoca*, the engineered organism can convert nitrates to ammonium, reducing the nutrient levels that cause harmful algal blooms and restoring ecosystem balance. 

To further extend the product's value chain, the resulting ammonium will then be converted into nutrient-rich products, utilizing bacterial native enzymatic machinery, through assimilation into amino acids, and subsequently into SCPs for agriculture as seen in Figure 1 (Long et al., 2017; Reihani & Khosravi-Darani, 2019; Zhang et al., 2021; Bojana Bajić et al., 2022; Zeng et al., 2022; Ding et al., 2023; Zeng et al., 2023; Zhang et al., 2023). This then facilitates upcycling while reducing agricultural production, as SCPs can be used to enhance livestock diets, reduce the need for additional fertilizers, and improve organic fertilizers' quality.


![Assimilatory nitrate (NO3–) reduction to ammonium (NH4+) and conversion to SCPs pathway in V. natriegens](https://static.igem.wiki/teams/5306/scheme-assimilatory-pathway.png)

**Figure 1.** Assimilatory nitrate (NO<sub>3</sub><sup>–</sup>) reduction to ammonium (NH<sub>4</sub><sup>+</sup>) and conversion to SCPs pathway in *V. natriegens*. The enzymes from *Klebsiella oxytoca* (shown in blue) would be incorporated into the organism to engineer the NO<sub>3</sub><sup>–</sup> assimilatory reduction to NH<sub>4</sub><sup>+</sup> pathway: addition of the NO<sub>3</sub><sup>–</sup> transporter, NO<sub>3</sub><sup>–</sup> reductase (Nas), and nitrite (NO<sub>2</sub><sup>–</sup>) reductase (Nir) enabling NO<sub>3</sub><sup>–</sup> reduction to NH<sub>4</sub><sup>+</sup>. Further assimilation of NH<sub>4</sub><sup>+</sup> through the glutamine synthetase (GS) - glutamate synthase (GOGAT) and nicotinamide adenine dinucleotide phosphate (NADPH)-dependent glutamate dehydrogenase (GDH) pathways enable glutamate biosynthesis (Ohashi et al., 2011; van Heeswijk et al., 2013; Jiang & Jiao, 2016). This accelerates protein synthesis and growth promoting the accumulation of SCPs. Created with [BioRender.com](https://www.biorender.com/).

For the prevention of the organism’s spread, potentially resulting in ecosystem imbalances, it will be encapsulated in a semi-permeable membrane chamber facilitating flow through whilst containing the GMO. This design aspect further facilitates the ease of harvesting our upcycled products.

## The Problem

---

With the rapid and sustained increase in population growth in the last 50 years, the agricultural sector has implemented the use of synthetic fertilizers to keep up with crop production.

![World population supported by synthetic nitrogen fertilizers](https://static.igem.wiki/teams/5306/graph-dependence-on-fertilizers.png)

**Figure 2.** Increasing population dependency on synthetic fertilizers. To sustain the increasing population, a proportional increase in reliance on synthetic fertilizers can be observed. In 2015, this substantially increased to half the world’s population (Erisman et al., 2008).

![Excess nitrogen from croplands](https://static.igem.wiki/teams/5306/world-map-excess-nitorgen-form-croplands.png)

**Figure 3.** Loss of nitrogen to the environment across the world. Excessive use of fertilizers leads to nitrogen overload exacerbating the issue of nitrogen imbalance in soil and water (West et al., 2014).

A major component in such fertilizers is nitrates. With this conventional intensification, accompanied by depleted soil from monocropping to sustain food and fodder demand, a large portion of fertilizer is unabsorbable. Their runoff into water bodies leads to eutrophication as the nitrates provide nutrients for algae, facilitating bloom (Figure 5). As such, the Netherlands’ position as a global agricultural powerhouse, with 54% of its surface area used as farmland, has led it to develop the worst water quality in the EU (Fraters et al., 2021). Rainfall and irrigation have caused runoff from agricultural areas to spread through the highly interconnected river system and into the Dutch coastline. This process is especially heightened in the Netherlands as major agricultural provinces, such as  Noord-Brabant, Gelderland and Zuid-Holland in the country are are characterized by a highly interconnected watershed network, where rivers, streams, and tributaries eventually discharge into the sea.   This creates a direct pathway for nutrient runoff from farmlands into marine ecosystems. 
(Ærtebjerg et al., 2001;Groendo , 2018)

Furthermore these anthropogenic activities have led to the development of marine dead zones due to the hypoxic and toxic conditions related to nitrate-induced algal bloom and decomposition (Figure 5). As the nitrogenous compounds  are uptaken by present algae for nutrients, the resultant algal bloom has a wide array of consequences. The overgrowth of algae first leads to the blockage of sunlight for the shallow primary producers of the marine food chains. As such, these plants are unable to perform photosynthesis and die, causing damaging rippling affects across the food web. Additionally, some of these algae produce toxins, leading to harmful algal blooms (HABs), directly poisoning local life. As this algae begins to decay due to nutrient depletion and overpopulation,  bacterial decomposers break down this organic matter. This decomposition process uptakes large amounts of dissolved oxygen in the water bodies, creating hypoxic conditions. These hypoxic conditions create dead zones that have insufficient oxygen to support marine life. Fish and other marine life either migrate to oxygen rich areas or die off. This leads to a loss of coastal biodiversity, while subsequently posing dangers to human health as well (Sanseverino et al., 2016). Another byproduct of algal decomposition is the release of carbon dioxide into the water. Carbon dioxide dissolves in the water, forming carbonic acid (H₂CO₃), lowering the pH of the water, contributing to ocean acidification.  Such acidification decreases the availability of calcium carbonate which is crucial for marine organisms like corals, mollusks and plankton physiology (Rastelli et al., 2020). Oxygen depletion and ocean acidification have also have shown to lead to mass proliferation of hypoxia tolerant species such as Noctiluca scintillans, which is toxic to fish, and damage to shallow marine vegetation (do Rosário Gomes et al., 2014; Glibert, 2017.) 

![Global distribution of the marine eutrophication characterization factors](https://static.igem.wiki/teams/5306/world-map-distribution-of-marine-eutrophication.jpg)

**Figure 5.** Global distribution of the marine eutrophication characterization factors in damage level units (Cosme & Hauschild, 2017).

![World map detailing marine dead zones](https://static.igem.wiki/teams/5306/world-map-marine-dead-zones.jpg)

**Figure 6.** World map detailing marine dead zones, hypoxia-induced coral reef mortality, and coral reef presence and densities. High density of dead zones can be observed in the North Sea, attributed to the excess nitrogen run-off-induced hypoxia (Altieri et al., 2017).

## Our Inspiration and Solution

---

### Coastal Eutrophication

As a team, we were primarily inspired by seeing the severe algal bloom state of our local water bodies, in particular, the pond situated next to our university library(Figure 7).

![De Vijf Koppen, Stadspark, Maastricht](https://static.igem.wiki/teams/5306/tapijn-eutrophication.jpg)

**Figure 7.** De Vijf Koppen, Stadspark, Maastricht. Picture taken by our team member, Devyani Ravi, on June 7th, 2024.

We immediately saw a need for new innovative solutions to manage and mitigate eutrophication. Noting the severity of the problem, our team was further inspired by freshwater eutrophication projects of previous iGEM teams ([Dusseldorf 2020](https://2020.igem.org/Team:Duesseldorf/Eutrophication), [Wageningen 2021](https://2021.igem.org/Team:Wageningen_UR), [Anatolia 2022](https://2022.igem.wiki/anatolia-college-hs/index.html), [Wego-Taipei 2022](https://2022.igem.wiki/wego-taipei/), [Bonn-Rherinbach 2023](https://2023.igem.wiki/bonn-rheinbach/)). The decision to focus on coastal areas was made for a more global approach, while simultaneously giving our team a concrete location for our GMO.As this is both a local and a worldwide problem, this decision gives the less acknowledged area of marine eutrophication bioremediation the attention we believe that it deserves. Prevention of the coastal spread is essential for marine biodiversity which directly faces the consequences of eutrophication such as harmful algal blooms (HABs), hypoxia, and ecosystem degradation (Marine, 2024). This disrupts food chains and the overall health of marine environments. These algal blooms can also have detrimental consequences for human health such as exotoxins both in marine accumulation and airborne (Sanseverino et al., 2016). 

### Nitrate Bioremediation
Among the various forms of nitrogenous compounds in fertilizers, which are often applied as ammonia, we specifically chose nitrates for an important reason (Annis, 2004). When ammonia is applied as a fertilizer, it binds with compounds in the soil such as organic matter, clay, and water. The reaction between ammonia and water produces ammonium, a cation with a positive charge. This positive charge makes ammonium relatively stable in soil. However, excess ammonia and ammonium ions can be converted into nitrates by nitrifying bacteria in the soil. Nitrates, which carry a partial negative charge due to resonance structures, are highly soluble in water, which has a partially positive charge. As a result, nitrates are far less stable in soil and are easily leached out during runoff and leaching (Paśmionka et al., 2021). This makes nitrates the prime candidate for bioremediation efforts aimed at reducing eutrophication caused by agricultural practices, which are a dominant source of nitrogen pollution in the Netherlands.

### Background Information on *V. natriegens*

*V. natriegens* is a gram-negative facultatively anaerobic marine bacterium (Thoma & Blombach., 2021). First isolated in 1958 from marsh mud from Sapelo Island in Georgia,  it has only recently garnered interest from the scientific community due to the exceptional doubling time of less than 10 min (Payne, 1958). The optimal growth conditions for V. natriegens are 15 g/L NaCl, 37 °C, and a pH of 7.5 (Thoma & Blombach., 2021). While Na+ is essential for the proliferation of V. natriegens, the bacterium is still able to maintain metabolic activity in its absence (Thoma & Blombach., 2021). Over the years, several iGEM teams, including Marburg 2018 and SCU-China 2021, have used V. natriegens as a tool for accelerating the development of innovative solutions in synthetic biology. 

Deciding on application in marine environments, we looked to V. Natriegens as our primary chassis organism. Not only can it survive in high salinity environments but is also a fast-growing bacterium gaining attention in synthetic biology applications, set to rival the more traditional E. Coli. The rapid growth rate and potential for using waste substrates into high-value products inspired us to explore its application for addressing nutrient pollution and  for the production of SCPs (Bojana Bajić et al., 2022). 

### Single-Cell Protein (SCP) Production

SCPs are a nutrient-dense, sustainable, and environmentally friendly alternative to conventional protein sources (e.g., soya, livestock, and fish) produced from biomass such as bacteria. For decades, SCP production has been researched for its benefits to our nutrition.

At the core of our project lies the concept of promoting circular economies within synthetic biology research. Rather than merely focusing on reducing nutrient inputs, we wanted to convert this waste into high-value products. We aim to engineer V. Natreigens into a single-cell protein powerhouse by turning waste nitrates from polluted water systems into ammonia which is integral for amino acid production. These amino acids make SCPs a versatile supplement for animal feed. This not only helps in reducing the nutrient load in water bodies to reduce algal blooms, but also adds economic value.

